# Generated by Django 4.2.3 on 2023-10-14 12:32

from django.db import migrations
import djangoldp.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_profile', '0008_alter_profile_available'),
    ]

    operations = [
        migrations.AlterField(
            model_name='profile',
            name='urlid',
            field=djangoldp.fields.LDPUrlField(blank=True, db_index=True, null=True, unique=True),
        ),
    ]
