# Generated by Django 4.2.3 on 2023-07-10 13:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_profile', '0007_auto_20200617_1817'),
    ]

    operations = [
        migrations.AlterField(
            model_name='profile',
            name='available',
            field=models.BooleanField(blank=True, null=True),
        ),
    ]
