# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2020-04-16 11:57
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_profile', '0002_auto_20190917_1141'),
    ]

    operations = [
        migrations.RenameField(
            model_name='profile',
            old_name='bio',
            new_name='job',
        ),
    ]
